@@ -54,7 +54,8 @@ class Int(NumberValueInterface):
             expression=expression)
 
     def set_value_and_skip_expression_appending(
-            self, value: Union[int, float, Any]) -> None:
+            self,
+            value: Union[int, float, NumberValueInterface, Any]) -> None:
         """
         Update value attribute and skip expression appending.
 
@@ -66,14 +67,14 @@ class Int(NumberValueInterface):
         """
         from apyscript.converter import cast
         from apyscript.validation import number_validation
-        number_validation.validate_num(num=value)
+        number_validation.validate_num(num=value)  # type: ignore
         if isinstance(value, NumberValueInterface):
             value._value = cast.to_int_from_float(int_or_float=value._value)
             value_ = value._value
         else:
             value = cast.to_int_from_float(int_or_float=value)
             value_ = value
-        self._value = value_
+        self._value = value_  # type: ignore
 
     def __repr__(self) -> str:
         """
