@@ -1,11 +1,12 @@
 """String's validation implementations.
 """
 
-from typing import Any
 from typing import Union
 
+from apyscript.type import String
 
-def validate_string_type(string: Union[str, Any]) -> None:
+
+def validate_string_type(string: Union[str, String]) -> None:
     """
     Validate specified string's type is str.
 
@@ -21,19 +22,18 @@ def validate_string_type(string: Union[str, Any]) -> None:
     """
     if isinstance(string, str):
         return
-    from apyscript.type import String
     if isinstance(string, String):
         return
     raise ValueError(f'Specified value is not str type: {type(string)}')
 
 
-def validate_not_empty_string(string: str) -> None:
+def validate_not_empty_string(string: Union[str, String]) -> None:
     """
     Validate specified string is not empty.
 
     Parameters
     ----------
-    string : str
+    string : str or String
         String to check.
 
     Raises
